@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.2.3 date 2005-08-19
+ * version 0.2 date 2005-03-07
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -26,7 +26,7 @@ static inline unsigned char Code3Bcd2Byte( unsigned char * pCode, unsigned char
 }
 
 //convert 5 BCD digits to a word
-static inline unsigned short Code5Bcd2Word( unsigned char * pCode, unsigned char Pos )
+static inline unsigned char Code5Bcd2Word( unsigned char * pCode, unsigned char Pos )
 {
   //word starts at even position
   if( (Pos & 0x01) == 0x00 )
