@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.2.3 date 2005-08-19
+ * version 0.2 date 2005-03-07
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -198,12 +198,7 @@ void EepromTask( void ) //(extern)
   //get address in EEPROM and data to write
   EEAR = EepromWriteDestAddr++;
   if( EepromWriteFlags & EepromWriteFlagCheck ) //check byte
-  {
     EEDR = ~*(pEepromWriteSrc++); //invert and advance source pointer
-    EepromWriteCnt--; //count down number of bytes to write
-    if( EepromWriteCnt <= 0 ) //finished
-      EepromWriteFlags &= ~EepromWriteFlagActive;
-  }
   else //not check byte
     EEDR = *pEepromWriteSrc; //use data byte as it is
   EepromWriteFlags ^= EepromWriteFlagCheck; //toggle check byte bit
