@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.2.3 date 2005-08-19
+ * version 0.2 date 2005-03-07
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -388,7 +388,7 @@ static void HttpProcessRequest( struct HttpConnection * pConn )
 //get a variable
 //pBuffer must provide space for at least 16 characters
 //returns the length of the variable
-static unsigned char HttpGetVariable( unsigned char VarNo, char * pBuffer, unsigned char MaxLen )
+static unsigned char HttpGetVariable( unsigned char VarNo, char * pBuffer )
 {
   switch( VarNo )
   {
@@ -402,8 +402,6 @@ static unsigned char HttpGetVariable( unsigned char VarNo, char * pBuffer, unsig
     case 0x86:
     case 0x87:
     case 0x88:
-      if( MaxLen < 3 )
-        return 0;
       if( OutputGet( VarNo - 0x80 ) )
       {
         memcpy( pBuffer, "ON", 2 );
@@ -424,8 +422,6 @@ static unsigned char HttpGetVariable( unsigned char VarNo, char * pBuffer, unsig
     case 0x96:
     case 0x97:
     case 0x98:
-      if( MaxLen < 1 )
-        return 0;
       if( OutputGet( VarNo - 0x90 ) )
         pBuffer[0] = '1';
       else
@@ -496,7 +492,7 @@ unsigned short HttpSend( unsigned char ConnNo, unsigned long Pos, unsigned char
   unsigned char i, var, VarLen, VarPos;
   struct HttpConnection * pConn;
   unsigned short len, j;
-  uint16_t src, srcTmp; //progmem pointer
+  uint16_t src; //progmem pointer
   char chr, * dest, VarBuffer[16];
 
   //find connection in table
@@ -532,11 +528,11 @@ unsigned short HttpSend( unsigned char ConnNo, unsigned long Pos, unsigned char
   {
     //get variable
     var = chr;
-    VarLen = HttpGetVariable( var, VarBuffer, sizeof( VarBuffer ) );
+    VarLen = HttpGetVariable( var, VarBuffer );
     //get position in variable
-    for( VarPos = 0, srcTmp = src - 1; srcTmp > pConn->pSndData; VarPos++, srcTmp-- )
-      if( (char)pgm_read_byte_near( srcTmp ) != var ) //if normal character or other variable, we found the begin of the variable
-        break;
+    for( VarPos = 0; src > pConn->pSndData; VarPos++, src-- )
+      if( (char)pgm_read_byte_near( src ) != var ) //if normal character of other variable, we found the begin of the variable
+        { VarPos++; break; }
   }
   //copy data to buffer
   dest = pBuffer;
@@ -552,7 +548,7 @@ unsigned short HttpSend( unsigned char ConnNo, unsigned long Pos, unsigned char
       {
         //get variable
         var = chr;
-        VarLen = HttpGetVariable( var, VarBuffer, sizeof( VarBuffer ) );
+        VarLen = HttpGetVariable( var, VarBuffer );
         VarPos = 0;
       }
       //copy next character of variable
@@ -564,8 +560,8 @@ unsigned short HttpSend( unsigned char ConnNo, unsigned long Pos, unsigned char
     //normal character
     else
     {
-      var = 0; //not a variable
-      *dest = chr; //copy character
+      *dest = chr;
+      VarPos = 0; //reset variable position (needed if same variable appears two times in a row)
     }
     //next character
     src++;
