@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.2.3 date 2005-08-19
+ * version 0.2 date 2005-03-07
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -19,7 +19,7 @@
 #include "udp.h"
 
 //timing parameters
-#define IpBufferTicksMax 50 //maximum age of buffered IP packet (in 200ms steps)
+#define IpBufferTicksMax 50 //maximum age of buffered IP pakcet (in 200ms steps)
 
 //buffers for IP packets to transmit
 // - used if MAC is unknown when packet shall be transmitted
