@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.2.3 date 2005-08-19
+ * version 0.2 date 2005-03-07
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -8,7 +8,6 @@
 #include <avr/io.h>
 #include <avr/interrupt.h>
 #include <avr/signal.h>
-#include <avr/wdt.h>
 
 #include "config.h"
 #include "ethernet.h"
@@ -315,10 +314,6 @@ static inline void RtlRecv( void )
   PacketLen = count( Packet );
   RtlReadFrame( Packet, &PacketLen );
 
-  //this is not very good in interrupt
-  // - but what else shall we do in case of heavy network load?
-  wdt_reset( );
-
   //pass packet on to ethernet
   EthernetRecv( Packet, PacketLen );
 }
